Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1764)

Unified Diff: chrome/browser/gtk/options/content_page_gtk.h

Issue 1124005: gtk: Tie the AutoFill button in the options dialog to the kEnableAutoFill pre... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/gtk/options/content_page_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/gtk/options/content_page_gtk.h
===================================================================
--- chrome/browser/gtk/options/content_page_gtk.h (revision 42276)
+++ chrome/browser/gtk/options/content_page_gtk.h (working copy)
@@ -48,7 +48,7 @@
// Initialize the option group widgets, return their container.
GtkWidget* InitPasswordSavingGroup();
- GtkWidget* InitFormAutofillGroup();
+ GtkWidget* InitFormAutoFillGroup();
GtkWidget* InitBrowsingDataGroup();
GtkWidget* InitThemesGroup();
GtkWidget* InitSyncGroup();
@@ -60,8 +60,8 @@
CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnSystemTitleBarRadioToggled);
CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnShowPasswordsButtonClicked);
CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnPasswordRadioToggled);
- CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnAutofillButtonClicked);
- CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnAutofillRadioToggled);
+ CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnAutoFillButtonClicked);
+ CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnAutoFillRadioToggled);
CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnSyncStartStopButtonClicked);
CHROMEGTK_CALLBACK_0(ContentPageGtk, void, OnSyncActionLinkClicked);
CHROMEGTK_CALLBACK_1(ContentPageGtk, void, OnStopSyncDialogResponse, int);
@@ -70,9 +70,10 @@
GtkWidget* passwords_asktosave_radio_;
GtkWidget* passwords_neversave_radio_;
// Widgets for the Form Autofill group.
GtkWidget* form_autofill_enable_radio_;
GtkWidget* form_autofill_disable_radio_;
+ GtkWidget* autofill_button_;
// Widgets for the Appearance group.
GtkWidget* system_title_bar_show_radio_;
« no previous file with comments | « no previous file | chrome/browser/gtk/options/content_page_gtk.cc » ('j') | no next file with comments »
@@ -70,9 +70,10 @@
GtkWidget* passwords_asktosave_radio_;
GtkWidget* passwords_neversave_radio_;
- // Widgets for the Form Autofill group.
+ // Widgets for the Form AutoFill group.
GtkWidget* form_autofill_enable_radio_;
GtkWidget* form_autofill_disable_radio_;

Powered by Google App Engine
This is Rietveld 408576698